function [cvverr] = CvvReg(ResponseVariable,nMaxRegressors,DataFileName,CvvFileName,nChainIterations,nCvvFold,regs,nregs)
    %some parameters needed for simulation
    tau = 1;
    delta = 2;

    SimFileName = sprintf('%s.%d.%d.cvv',CvvFileName,ResponseVariable,nregs);
    simfile = fopen(SimFileName,'w');
    
    %load the dataset
    data = load(DataFileName);
    nSampleSize = size(data,1);    
    mysamples = zeros(nSampleSize,nChainIterations);
    
    [data,idesc] = interactdata(data,ResponseVariable,regs,nregs);
    
    cvvorder = randperm(nSampleSize);
    blocksize = floor(nSampleSize/nCvvFold);
 
    for(asplit=1:nCvvFold)
        fprintf('Cvv split [%d]\n',asplit); 
        
        firstsample = (asplit-1)*blocksize+1;
        lastsample = (asplit-1)*blocksize+blocksize;
        if(asplit==nCvvFold)
            lastsample = nSampleSize;
        end;
        
        valsamples = cvvorder(firstsample:lastsample);        
        mydata = data;
        mydata(valsamples,:) = [];
        
        %sample size
        n = size(mydata,1);
        
        regweight = zeros(1,nregs);
        for(i=1:nregs)
            regweight(i) = getregpost(ResponseVariable,regs{i},mydata);
        end;
        %normalize the weights
        regweight = exp(regweight-max(regweight));
        regweight = regweight/sum(regweight);
        
        %calculate the weights for sampling
        w = zeros(1,nregs+1);
        for(i=2:length(w))
            w(i) = w(i-1)+regweight(i-1);
        end;
        
        Y = mydata(:,ResponseVariable);
        %for(iteration=1:nChainIterations)
        iteration=1;
        while(iteration<=nChainIterations)
            %sample a regression according to the weights
            a = rand(1);
            for(myreg=1:nregs)
                if((a>=w(myreg))&(a<w(myreg+1)))
                    break;
                end;
            end;
            pred = regs{myreg};
            npred = length(pred);
            
            %simulate regression parameters
            if(0==npred)
                nu = tau+sum(Y.*Y);
                psi = 1/gamrnd((delta+n)/2,2/nu);
                for(i=1:length(valsamples))
                    mysamples(valsamples(i),iteration) = normrnd(0,psi);
                end;
                iteration = iteration+1;
            else
                X = mydata(:,pred);
                M = tau*eye(npred)+X'*X;
                R = M\(X'*Y);
                nu = tau+Y'*Y-Y'*X*R;
                psi = 1/gamrnd((delta+npred+n)/2,2/nu);
                Minv=M\eye(npred);
                [Rtest,ptest] = chol(psi*Minv);
                if(0==ptest)
                    %regcoef = mvnrnd(R',psi*Minv);
                    regcoef = randn(1,size(Rtest,1)) * Rtest + R';
                    for(i=1:length(valsamples))
                        mysamples(valsamples(i),iteration) = sum(data(valsamples(i),pred).*regcoef);
                    end;
                    iteration = iteration+1;
                end;
                %regcoef = mvnrnd(R',psi*Minv);
                %for(i=1:length(valsamples))
                %    mysamples(valsamples(i),iteration) = sum(data(valsamples(i),pred).*regcoef);
                %end;
                %iteration = iteration+1;
            end;
        end;
    end;
    
    for(asample=1:nSampleSize)
        a = prctile(mysamples(asample,:),[5 50 95]);
        fprintf(simfile,'%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n',data(asample,ResponseVariable),mean(mysamples(asample,:)),a(1),a(2),a(3));
    end;
    fclose(simfile);
    
    ErrFileName = sprintf('%s.%d.%d.cvverr',CvvFileName,ResponseVariable,nregs);
    errfile = fopen(ErrFileName,'w');
    err = zeros(1,nChainIterations);
    a = data(:,ResponseVariable);
    for(iteration=1:nChainIterations)
        b = mysamples(:,iteration);
        residuals = b-a-mean(b-a);
        err(iteration) = 1-sum(residuals.*residuals)/sum(a.*a);
    end;
    a = prctile(err,[2.5 50 97.5]);
    fprintf(errfile,'%.5f\t%.5f\t%.5f\t%.5f\n',mean(err),a(1),a(2),a(3));
    fclose(errfile); 
    
    cvverr = a(2);
    return;