function [rcL,rcE,rcU] = FittedRegCoef(ResponseVariable,nMaxRegressors,DataFileName,nChainIterations,regs,nregs)
    %some parameters needed for simulation
    tau = 1;
    delta = 2;
    
    %load the dataset
    data = load(DataFileName);
    nSampleSize = size(data,1); 
    
    mysamples = zeros(nSampleSize,nChainIterations);
    [mydata,idesc] = interactdata(data,ResponseVariable,regs,nregs);
        
    %sample size
    n = size(mydata,1);
        
    regweight = zeros(1,nregs);
    for(i=1:nregs)
        regweight(i) = getregpost(ResponseVariable,regs{i},mydata);
    end;
    %normalize the weights
    regweight = exp(regweight-max(regweight));
    regweight = regweight/sum(regweight);
        
    %calculate the weights for sampling
    w = zeros(1,nregs+1);
    for(i=2:length(w))
        w(i) = w(i-1)+regweight(i-1);
    end;
    
    Y = mydata(:,ResponseVariable);
    
    regcoefMatrix = sparse(nChainIterations,size(mydata,2));
    
    iteration=1;
    while(iteration<=nChainIterations)
        %fprintf('iteration [%d]\n',iteration);
        %sample a regression according to the weights
        a = rand(1);
        for(myreg=1:nregs)
            if((a>=w(myreg))&(a<w(myreg+1)))
                break;
            end;
        end;
        pred = regs{myreg};
        npred = length(pred);
            
        %simulate regression parameters
        if(0==npred)
            nu = tau+sum(Y.*Y);
            psi = 1/gamrnd((delta+n)/2,2/nu);
            for(i=1:nSampleSize)
                mysamples(i,iteration) = normrnd(0,psi);
            end;
            iteration = iteration+1;
        else
            X = mydata(:,pred);
            M = tau*eye(npred)+X'*X;
            R = M\(X'*Y);
            nu = tau+Y'*Y-Y'*X*R;
            psi = 1/gamrnd((delta+npred+n)/2,2/nu);
            Minv=M\eye(npred);
            [Rtest,ptest] = chol(psi*Minv);
            if(0==ptest)
                regcoef = randn(1,size(Rtest,1)) * Rtest + R';
                regcoefMatrix(iteration,pred) = regcoef;                
            end;
            iteration = iteration+1;
        end;
    end
    
    rcL = zeros(1,size(mydata,2));
    rcE = zeros(1,size(mydata,2));
    rcU = zeros(1,size(mydata,2));
    for(i=1:size(mydata,2))
        rcL(i) = prctile(regcoefMatrix(:,i),2.5);
        rcE(i) = prctile(regcoefMatrix(:,i),50);
        rcU(i) = prctile(regcoefMatrix(:,i),97.5);
    end;
    return;