function [] = FittedRegGraph(ResponseVariable,nMaxRegressors,DataFileName,FittedFileName,nChainIterations)
    %some parameters needed for simulation
    tau = 1;
    delta = 2;

    SimFileName = sprintf('%s.%d.%d.graphfitted',FittedFileName,ResponseVariable,nMaxRegressors);
    simfile = fopen(SimFileName,'w');
    
    %load the dataset
    data = load(DataFileName);
    nSampleSize = size(data,1);
    
    %load the regression models
    pred = loadRegGraph(DataFileName,ResponseVariable,nMaxRegressors);
    npred = length(pred);  
    
    mysamples = zeros(nSampleSize,nChainIterations);
            
    mydata = data;
        
    %sample size
    n = size(mydata,1);
               
    Y = mydata(:,ResponseVariable);
    for(iteration=1:nChainIterations)            
        %simulate regression parameters
        if(0==npred)
            nu = tau+sum(Y.*Y);
            psi = 1/gamrnd((delta+n)/2,2/nu);
            for(i=1:nSampleSize)
                mysamples(i,iteration) = normrnd(0,psi);
            end;
        else
            X = mydata(:,pred);
            M = tau*eye(npred)+X'*X;
            R = M\(X'*Y);
            nu = tau+Y'*Y-Y'*X*R;
            psi = 1/gamrnd((delta+npred+n)/2,2/nu);
            Minv=M\eye(npred);
            regcoef = mvnrnd(R',psi*Minv);
            for(i=1:nSampleSize)
                mysamples(i,iteration) = normrnd(sum(data(i,pred).*regcoef),psi);
            end;
        end;
    end;
    
    for(asample=1:nSampleSize)
        a = prctile(mysamples(asample,:),[5 50 95]);
        fprintf(simfile,'%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n',data(asample,ResponseVariable),mean(mysamples(asample,:)),a(1),a(2),a(3));
    end;
    fclose(simfile);
    
    ErrFileName = sprintf('%s.%d.%d.graphfiterr',FittedFileName,ResponseVariable,nMaxRegressors);
    errfile = fopen(ErrFileName,'w');
    err = zeros(1,nChainIterations);
    a = data(:,ResponseVariable);
    for(iteration=1:nChainIterations)
        b = mysamples(:,iteration);
        residuals = b-a-mean(b-a);
        err(iteration) = 1-sum(residuals.*residuals)/sum(a.*a);
    end;
    a = prctile(err,[2.5 50 97.5]);
    fprintf(errfile,'%.5f\t%.5f\t%.5f\t%.5f\n',mean(err),a(1),a(2),a(3));
    fclose(errfile);    
    return;