function [fiterr] = FittedSigma(ResponseVariable,DataFileName,FittedFileName,nChainIterations,dags)
    %some parameters needed for simulation
    tauPrior = 1;
    deltaPrior = 2;
    
    %load the data
    data = load(DataFileName);
    sampleSize = size(data,1);
    nvars = size(data,2);

    mysamples = zeros(sampleSize,nChainIterations);            
    
    mydata = data;
    
    %normalize the weights
    dags(:,3) = dags(:,3)/sum(dags(:,3));
    nmodels = length(dags(:,3));
    fprintf('Significant models found :: %d\n',nmodels);

    SimFileName = sprintf('%s.%d.%d.fitted',FittedFileName,ResponseVariable,nmodels);
    simfile = fopen(SimFileName,'w');
    
    %calculate the weights for sampling
    w = zeros(1,nmodels+1);
    for(i=2:length(w))
        w(i) = w(i-1)+dags(i-1,3);
    end;

    %load the models
    fprintf('Loading models...');
    mymodels = cell(1,nmodels);
    for(i=1:nmodels)
        dagpath = sprintf('%s.%d.%d.dag',DataFileName,dags(i,1),dags(i,2));
        mydag = load(dagpath);
        if(size(mydag,1)>=1)
           mymodels{i} = sparse(mydag(:,1),mydag(:,2),ones(size(mydag,1),1),nvars,nvars);
       end;
    end;
    fprintf('done\n\n');
    
    fprintf('Finding Markov blanchet...');
    markovBlanchet = cell(1,nmodels);
    for(i=1:nmodels)
        if(size(mymodels{i},1)>=1)
            G = indepgraph(mymodels{i});
            markovBlanchet{i} = find(G(ResponseVariable,:));
        end;
    end;
    fprintf('done\n\n');
    
    allregcoef = zeros(nChainIterations,size(data,2));
    
    for(iter=1:nChainIterations)
        
        %fprintf('Iteration [%d] ',iter);
        %generate a random model
        a = rand(1);
        for(mymodel=1:nmodels)
            if((a>=w(mymodel))&(a<w(mymodel+1)))
                break;
            end;
        end;
        %fprintf('selected model [%d]\n',mymodel);

         %simulate the model parameters
         %fprintf('Simulating regression parameters...');
         psi = zeros(nvars,1);
         M_gamma = zeros(nvars);
         for(resp=1:nvars)
             if(size(mymodels{mymodel},1)>=1)
                [ignore1,pred,ignore2] = find(mymodels{mymodel}(resp,:));
                npred = length(pred);
             else
                npred = 0;
             end;
             y = data(:,resp);
             
             if(0==npred)
                 nu = tauPrior+y'*y;
                 psi(resp) = 1/gamrnd((deltaPrior+sampleSize)/2,2/nu);
             else
                 X = data(:,pred);
                 M = tauPrior*eye(npred)+X'*X;
                 R=M\(X'*y);
                 %simulate the variance
                 nu = tauPrior+y'*y-y'*X*R;
                 mypsi = 1/gamrnd((deltaPrior+sampleSize+npred)/2,2/nu);
                 psi(resp) = mypsi;
                 %params of the normal distrib
                 Minv=M\eye(npred);
                 M_gamma(resp,pred) = mvnrnd(R',mypsi*Minv);
             end;
         end;
         %fprintf('done\n');

         %fprintf('Finding precision matrix...');
         M_phi = (eye(nvars) - M_gamma)'*full(sparse((1:nvars)',(1:nvars)',1./sqrt(psi),nvars,nvars));
         M_phi_inv = M_phi\eye(nvars);
         %fprintf('done\n');

         %now determine the correlation matrix
         %first calculate the variance of each variable
         %fprintf('Calculating correlations...');
 
         A = M_phi_inv;
         Sigma = A'*A; %covariance matrix
         d = sqrt(diag(Sigma));
         [i,j,s] = find(Sigma);
         s = s./d(i);
         s = s./d(j);
         Sigma = full(sparse(i,j,s,nvars,nvars));
         %fprintf('done\n');

         pred = markovBlanchet{mymodel};
         if(0==length(pred))
            for(i=1:sampleSize)
                mysamples(i,iter) = 0;
            end;
         else
            myvars = [ResponseVariable pred];
            Sigma = Sigma(myvars,myvars);
            Sigma12 = Sigma(1,2:size(Sigma,2));
            Sigma22 = Sigma(2:size(Sigma,1),2:size(Sigma,2));
            Sigma22inv = Sigma22\eye(size(Sigma22,1));
            regcoef = Sigma12*Sigma22inv;
            for(i=1:sampleSize)
                mysamples(i,iter) = sum(data(i,pred).*regcoef);
            end;
            allregcoef(iter,pred) = regcoef;
         end;
     end;
    
     for(asample=1:sampleSize)
        a = prctile(mysamples(asample,:),[5 50 95]);
        fprintf(simfile,'%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n',data(asample,ResponseVariable),mean(mysamples(asample,:)),a(1),a(2),a(3));
    end;
    fclose(simfile);
    
    ErrFileName = sprintf('%s.%d.%d.fiterr',FittedFileName,ResponseVariable,nmodels);
    errfile = fopen(ErrFileName,'w');
    err = zeros(1,nChainIterations);
    a = data(:,ResponseVariable);
    for(iteration=1:nChainIterations)
        b = mysamples(:,iteration);
        residuals = b-a-mean(b-a);
        err(iteration) = 1-sum(residuals.*residuals)/sum(a.*a);
    end;
    a = prctile(err,[2.5 50 97.5]);
    fprintf(errfile,'%.5f\t%.5f\t%.5f\t%.5f\n',mean(err),a(1),a(2),a(3));
    fclose(errfile);    
    
    fiterr = a(2);
    return;