function [fiterr] = FittedReg(ResponseVariable,nMaxRegressors,DataFileName,FittedFileName,nChainIterations,regs,nregs)
    %some parameters needed for simulation
    tau = 1;
    delta = 2;

    SimFileName = sprintf('%s.%d.%d.fitted',FittedFileName,ResponseVariable,nregs);
    simfile = fopen(SimFileName,'w');
    
    %load the dataset
    data = load(DataFileName);
    nSampleSize = size(data,1); 
    
    mysamples = zeros(nSampleSize,nChainIterations);
    [mydata,idesc] = interactdata(data,ResponseVariable,regs,nregs);
        
    %sample size
    n = size(mydata,1);
        
    regweight = zeros(1,nregs);
    for(i=1:nregs)
        regweight(i) = getregpost(ResponseVariable,regs{i},mydata);
    end;
    %normalize the weights
    regweight = exp(regweight-max(regweight));
    regweight = regweight/sum(regweight);
        
    %calculate the weights for sampling
    w = zeros(1,nregs+1);
    for(i=2:length(w))
        w(i) = w(i-1)+regweight(i-1);
    end;
    
    Y = mydata(:,ResponseVariable);
    
    iteration=1;
    while(iteration<=nChainIterations)
        %fprintf('iteration [%d]\n',iteration);
        %sample a regression according to the weights
        a = rand(1);
        for(myreg=1:nregs)
            if((a>=w(myreg))&(a<w(myreg+1)))
                break;
            end;
        end;
        pred = regs{myreg};
        npred = length(pred);
            
        %simulate regression parameters
        if(0==npred)
            nu = tau+sum(Y.*Y);
            psi = 1/gamrnd((delta+n)/2,2/nu);
            for(i=1:nSampleSize)
                mysamples(i,iteration) = normrnd(0,psi);
            end;
            iteration = iteration+1;
        else
            X = mydata(:,pred);
            M = tau*eye(npred)+X'*X;
            R = M\(X'*Y);
            nu = tau+Y'*Y-Y'*X*R;
            psi = 1/gamrnd((delta+npred+n)/2,2/nu);
            Minv=M\eye(npred);
            [Rtest,ptest] = chol(psi*Minv);
            if(0==ptest)
                %regcoef = mvnrnd(R',psi*Minv);
                regcoef = randn(1,size(Rtest,1)) * Rtest + R';
                for(i=1:nSampleSize)
                    mysamples(i,iteration) = sum(mydata(i,pred).*regcoef);
                end;
            end;
            iteration = iteration+1;
        end;
    end;
    
    for(asample=1:nSampleSize)
        a = prctile(mysamples(asample,:),[2.5 50 97.5]);
        fprintf(simfile,'%.2f\t%.2f\t%.2f\t%.2f\t%.2f\n',data(asample,ResponseVariable),mean(mysamples(asample,:)),a(1),a(2),a(3));
    end;
    fclose(simfile);
    
    ErrFileName = sprintf('%s.%d.%d.fiterr',FittedFileName,ResponseVariable,nregs);
    errfile = fopen(ErrFileName,'w');
    err = zeros(1,nChainIterations);
    a = data(:,ResponseVariable);
    for(iteration=1:nChainIterations)
        b = mysamples(:,iteration);
        residuals = b-a-mean(b-a);
        err(iteration) = 1-sum(residuals.*residuals)/sum(a.*a);
    end;
    a = prctile(err,[2.5 50 97.5]);
    fprintf(errfile,'%.5f\t%.5f\t%.5f\t%.5f\n',mean(err),a(1),a(2),a(3));
    fclose(errfile);
    
    fiterr = a(2);
    return;