function [avecor,allcoef] = bmaomega(niterations,apath,outputfile)
     rand('state',sum(100*clock));

     %load the data
     data = load(apath);
     sampleSize = size(data,1);
     nvars = size(data,2);

     %figure out the most significant models
     samplefile = sprintf('%s.sample',apath);
     dags = significantdags(samplefile);
     %normalize the weights
     dags(:,3) = dags(:,3)/sum(dags(:,3));
     nmodels = length(dags(:,3));
     fprintf('Significant models found :: %d\n',nmodels);

     %calculate the weights for sampling
     w = zeros(1,nmodels+1);
     for(i=2:length(w))
         w(i) = w(i-1)+dags(i-1,3);
     end;

     %load the models
     fprintf('Loading models...');
     mymodels = cell(1,nmodels);
     for(i=1:nmodels)
         dagpath = sprintf('%s.%d.%d.dag',apath,dags(i,1),dags(i,2));
         mydag = load(dagpath);
         if(size(mydag,1)>=1)
            mymodels{i} = sparse(mydag(:,1),mydag(:,2),ones(size(mydag,1),1),nvars,nvars);
        end;
     end;
     fprintf('done\n\n');
     %some parameters needed for simulation
     tauPrior = 1;
     deltaPrior = 2;
     
     allcoef = zeros(niterations,nvars*nvars);
     
     avecor = sparse(nvars,nvars);
     for(iter=1:niterations)
         tic; %keep track of the time needed for each iteration

         fprintf('Iteration [%d] ',iter);
         %generate a random model
         a = rand(1);
         for(mymodel=1:nmodels)
             if((a>=w(mymodel))&(a<w(mymodel+1)))
                 break;
             end;
         end;
         fprintf('selected model [%d]\n',mymodel);

         %simulate the model parameters
         fprintf('Simulating regression parameters...');
         psi = zeros(nvars,1);
         M_gamma = sparse(nvars,nvars);
         for(resp=1:nvars)
             if(size(mymodels{mymodel},1)>=1)
                [ignore1,pred,ignore2] = find(mymodels{mymodel}(resp,:));
                npred = length(pred);
             else
                npred = 0;
             end;
             y = data(:,resp);
             
            if(0==npred)
                 nu = tauPrior+y'*y;
                 psi(resp) = 1/gamrnd((deltaPrior+sampleSize)/2,2/nu);
             else
                 X = data(:,pred);
                 M = tauPrior*eye(npred)+X'*X;
                 R=M\(X'*y);
                 %simulate the variance
                 nu = tauPrior+y'*y-y'*X*R;
                 mypsi = 1/gamrnd((deltaPrior+sampleSize+npred)/2,2/nu);
                 psi(resp) = mypsi;
                 %params of the normal distrib
                 Minv=M\eye(npred);
                 M_gamma(resp,pred) = mvnrnd(R',mypsi*Minv);
             end;
         end;
         fprintf('done\n');
         
         fprintf('Finding precision matrix...');
         M_phi = (speye(nvars) - M_gamma)'*sparse((1:nvars)',(1:nvars)',1./sqrt(psi),nvars,nvars);
         fprintf('done\n');

         %now determine the correlation matrix
         %first calculate the variance of each variable
         fprintf('Calculating correlations...');
 
         Omega = M_phi*M_phi';
         d = sqrt(diag(Omega));
         [i,j,s] = find(Omega);
         s = s./d(i);
         s = s./d(j);
         Omega = sparse(i,j,s,nvars,nvars);
         allcoef(iter,:) = reshape(full(Omega),1,[]);
         avecor = avecor+Omega;
         fprintf('done\n');

         t = toc;
         fprintf('Elapsed time [%.2f] seconds.\n\n',t);
     end;

     [i,j,s]=find(avecor);
     s = s/niterations;
     fid = fopen(outputfile,'w');
     for(k=1:length(i))
         fprintf(fid,'%d\t%d\t%f\n',i(k),j(k),s(k));
     end;
     fclose(fid);
     fprintf('Number of significant correlations [%d]\n',length(s));
     %adjust the correlation values that are returned
     avecor = sparse(i,j,s,nvars,nvars);