DataFileName = '/Users/adobra/Projects/LargeRegression/Continuous/Datasets/simulated/athousand/sim100x1000.txt';
FittedFileName = '/Users/adobra/Projects/LargeRegression/Continuous/Datasets/simulated/athousand/Fitted/sim100x1000.txt';
CvvFileName = '/Users/adobra/Projects/LargeRegression/Continuous/Datasets/simulated/athousand/Cvv/sim100x1000.txt';
ResponseVariable = 1;
nMaxRegressorsMin = 2;
nMaxRegressorsMax = 20;
nChainIterations = 10000; %number of simulations for each sample
nCvvFold = 5;

rand('state',sum(100*clock));
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
  fprintf('processing [%d] [%d]\n',ResponseVariable,nMaxRegressors);
  FittedRegGraph(ResponseVariable,nMaxRegressors,DataFileName,FittedFileName,nChainIterations);
  CvvRegGraph(ResponseVariable,nMaxRegressors,DataFileName,CvvFileName,nChainIterations,nCvvFold);
end;

%plot this information
fitinfo = zeros(nMaxRegressorsMax-nMaxRegressorsMin+1,4);
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
   fitinfo(nMaxRegressors-nMaxRegressorsMin+1,:) = load(sprintf('%s.%d.%d.graphfiterr',FittedFileName,ResponseVariable,nMaxRegressors)); 
end;

cvvinfo = zeros(nMaxRegressorsMax-nMaxRegressorsMin+1,4);
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
   cvvinfo(nMaxRegressors-nMaxRegressorsMin+1,:) = load(sprintf('%s.%d.%d.graphcvverr',CvvFileName,ResponseVariable,nMaxRegressors)); 
end;

subplot(2,2,1);
hold on;
set(gca,'ygrid','on');
shift = 0.2;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    plot(nMaxRegressors,fitinfo(nMaxRegressors-nMaxRegressorsMin+1,1),'bo',nMaxRegressors+shift,cvvinfo(nMaxRegressors-nMaxRegressorsMin+1,1),'rx');
end;
legend('Fitted','Cross-validation');

for(nMaxRegressors=nMaxRegressorsMin:(nMaxRegressorsMax-1))
    i = nMaxRegressors-nMaxRegressorsMin+1;
    plot([nMaxRegressors nMaxRegressors+1],[fitinfo(i,1) fitinfo(i+1,1)],'b-');
end;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    i = nMaxRegressors-nMaxRegressorsMin+1;
    plot([nMaxRegressors nMaxRegressors],[fitinfo(i,2) fitinfo(i,4)],'b-');
end;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    plot(nMaxRegressors,fitinfo(nMaxRegressors-nMaxRegressorsMin+1,2),'b^');
end;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    plot(nMaxRegressors,fitinfo(nMaxRegressors-nMaxRegressorsMin+1,4),'bv');
end;

for(nMaxRegressors=nMaxRegressorsMin:(nMaxRegressorsMax-1))
    i = nMaxRegressors-nMaxRegressorsMin+1;
    plot([nMaxRegressors+shift nMaxRegressors+1+shift],[cvvinfo(i,1) cvvinfo(i+1,1)],'r-');
end;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    i = nMaxRegressors-nMaxRegressorsMin+1;
    plot([nMaxRegressors+shift nMaxRegressors+shift],[cvvinfo(i,2) cvvinfo(i,4)],'r-');
end;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    plot(nMaxRegressors+shift,cvvinfo(nMaxRegressors-nMaxRegressorsMin+1,2),'r^');
end;
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
    plot(nMaxRegressors+shift,cvvinfo(nMaxRegressors-nMaxRegressorsMin+1,4),'rv');
end;
xlim([1 nMaxRegressorsMax+1]);
xlabel('Maximum Regressors');
ylabel('Squared Error');
set(gca,'xtick',(nMaxRegressorsMin-1):(nMaxRegressorsMax+1));
hold off;

subplot(2,2,2);
nvars = zeros(nMaxRegressorsMax-nMaxRegressorsMin+1,2);
nsum = zeros(nMaxRegressorsMax-nMaxRegressorsMin+1,1);
for(nMaxRegressors=nMaxRegressorsMin:nMaxRegressorsMax)
   a = loadRegGraph(DataFileName,ResponseVariable,nMaxRegressors);
   nvars(nMaxRegressors-nMaxRegressorsMin+1,1) = length(find(a<=10));
   nvars(nMaxRegressors-nMaxRegressorsMin+1,2) = length(find(a>=111));
   nsum(nMaxRegressors-nMaxRegressorsMin+1) = length(a);
end;
bar(nMaxRegressorsMin:nMaxRegressorsMax,nvars,'stack');
xlim([1 nMaxRegressorsMax+1]);
ylim([0 max(nsum)+1]);
set(gca,'xtick',1:2:(nMaxRegressorsMax-nMaxRegressorsMin+1));
set(gca,'ytick',0:2:(max(nsum)+1));
xlabel('Maximum Regressors');
ylabel('Regressors Involved');

subplot(2,2,3);
b = nMaxRegressorsMin:nMaxRegressorsMax;
nMaxRegressors = b(min(find(cvvinfo(:,1)==min(cvvinfo(:,1)))));
a = load(sprintf('%s.%d.%d.graphfitted',FittedFileName,ResponseVariable,nMaxRegressors));
hold on;
for(i=1:size(a,1))
    plot(a(i,1),a(i,2),'b.');
end;
for(i=1:size(a,1))
    plot([a(i,1) a(i,1)],[a(i,3) a(i,5)],'b-');
end;
amin = min(min(a(:,1)),min(a(:,2)))-0.1;
amax = max(max(a(:,1)),max(a(:,2)))+0.1;
xlim([amin amax]);
ylim([amin amax]);
xlabel('Observed Values');
ylabel('Fitted');
title(sprintf('Maximum Regressors = %d',nMaxRegressors));
hold off;
grid on;

subplot(2,2,4);
a = load(sprintf('%s.%d.%d.graphcvv',CvvFileName,ResponseVariable,nMaxRegressors));
hold on;
for(i=1:size(a,1))
    plot(a(i,1),a(i,2),'b.');
end;
for(i=1:size(a,1))
    plot([a(i,1) a(i,1)],[a(i,3) a(i,5)],'b-');
end;
amin = min(min(a(:,1)),min(a(:,2)))-0.1;
amax = max(max(a(:,1)),max(a(:,2)))+0.1;
xlim([amin amax]);
ylim([amin amax]);
xlabel('Observed Values');
ylabel('Cross-validation');
title(sprintf('Maximum Regressors = %d',nMaxRegressors));
hold off;
grid on;