%This function find the dags that are significant and should be analyzed
%further.
function [mysample] = significantdags(samplefile)
    mysample = load(samplefile);
    
    %find the dag with the largest posterior weight
    bestdag = find(mysample(:,4)==max(mysample(:,4)));
    bestdag = bestdag(length(bestdag));    

    %determine which dags have a significant posterior weight
    %with respect to the weight of the best dag
    myweight = exp(mysample(:,4)-mysample(bestdag,4));
    ind = find(myweight<0.01);
    %eliminate all the non-significant dags
    mysample(ind,:) = [];
    %find again the index of the best dag
    bestdag = find(mysample(:,4)==max(mysample(:,4)));
    bestdag = bestdag(length(bestdag));
    mysample(:,4) = exp(mysample(:,4)-mysample(bestdag,4));
    mysample = mysample(:,[1 2 4]);
    
    %some dags might have the same posterior weight; this indicates
    %that they belong to the same equivalence class; we keep only
    %one dag for each equivalence class
    ndags = size(mysample,1);
    tokeep = zeros(1,ndags);
    uweigths = unique(mysample(:,3));
    for(i=1:length(uweigths))
        ind = find(mysample(:,3)==uweigths(i));
        tokeep(ind(length(ind))) = 1;
    end;
    ind = find(1-tokeep);
    mysample(ind,:)=[];
    [b,ind] = sort(-mysample(:,3));
    mysample = mysample(ind,:);