/*
AUTHOR: ADRIAN DOBRA (ADOBRA@STAT.WASHINGTON.EDU)
*/

// dgraph.cpp: implementation of the DGraph class.
//
//////////////////////////////////////////////////////////////////////
#include <string>
#include <stdio.h>
#include "dgraph.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

DGraph::DGraph(const char* GraphFile, int nvertices)
{
	InitGraph(nvertices);
	ReadGraph(GraphFile);
}

DGraph::DGraph(int nvertices)
{
	InitGraph(nvertices);
}

DGraph::~DGraph()
{
	DeleteGraph();
}

//////////////////////////////////////////////////
//initializes "nvertices" lists of neighbours
//corresponding with vertices 0,1,...,nvertices-1.
//////////////////////////////////////////////////
void DGraph::InitGraph(int nvertices)
{
	int i;
	mnvertices = nvertices;
	graph  = new set<int>[mnvertices];
}

void DGraph::DeleteGraph()
{
	delete[] graph; graph = NULL;
}

//adds an edge between vertices "vi" and "vj"
//in the graph "graph"
void DGraph::AddEdge(int vi,int vj)
{
	graph[vi].insert(vj);
}

//eliminates edge (vi,vj) from graph "graph"
void DGraph::DeleteEdge(int vi,int vj)
{
	graph[vi].erase(vj);
}

void DGraph::PrintGraph(FILE* out)
{
	int i;
	for(i=0;i<mnvertices;i++)
	{
		fprintf(out, "%d ", graph[i].size());
		for(set<int>::iterator it = graph[i].begin(); it != graph[i].end(); it++)
		{
			fprintf(out, " %d", *it);
		}
		fprintf(out, "\n");
	}
	return;
}

void DGraph::SaveGraph(char* filePath)
{
	FILE* out = fopen(filePath,"w");
	if(NULL==out)
	{
		fprintf(stderr, "Failed saving the model.\n");
		return;
	}
	PrintGraph(out);
	fclose(out);
	return;
}

void DGraph::ReadGraph(const char* GraphFile)
{
	FILE* infile = fopen(GraphFile,"r");
	if(NULL==infile)
	{
		printf("Cannot open file :: %s\n",GraphFile);
		exit(1);
	}

	int i,j;
	while(!feof(infile))
	{
		if(2!=fscanf(infile,"%d %d", &i,&j))
		{
			break;
		}
		AddEdge(i-1,j-1);
	}      
	fclose(infile);
	return;
}

int DGraph::IsEdge(int target,int v)
{
	return (graph[target].find(v) != graph[target].end());
}