/*
 *  largeregcont.cpp
 *  
 *
 *  Created by Adrian Dobra on 11/22/06.
 *  Copyright 2006 __University of Washington__. All rights reserved.
 *
 */

#include "largeregcont.h"

int qsortcompare(const void * a, const void * b)
{
	int ia = *(int*)a;
	int ib = *(int*)b;
	
	if(probs[ia]>probs[ib]) return(-1);
	if(probs[ia]<probs[ib]) return(1);
	return(0);
}

void searchRespReg(int target,int maxreg,double* probs)
{
	double epsilon = 0.001;
	int i;
	double s;
	char buffer[1024];
	FILE* out = NULL;
	
	GS.nMaxRegressors = maxreg;
	
	sprintf(buffer,"%s.%d.%d.reg",sDataFile,target,maxreg);
	if(NULL==(out=fopen(buffer,"w")))
	{
		printf("Cannot open file [%s]\n",buffer);
		return;
	}
	GS.hybridReg(target-1,Data,probs,out);
	fclose(out);

	int index[Data.NumberOfGenes];
	for(i=0;i<Data.NumberOfGenes;i++)
	{
		index[i] = i;
	}
	qsort(index,Data.NumberOfGenes,sizeof(int),qsortcompare);
	
	sprintf(buffer,"%s.%d.%d.var",sDataFile,target,maxreg);
	if(NULL==(out=fopen(buffer,"w")))
	{
		printf("Cannot open file [%s]\n",buffer);
		return;
	}
		
	for(i=0;i<Data.NumberOfGenes;i++)
	{
		if(index[i]!=(target-1))
		{
			if(probs[index[i]]>=epsilon)
			{
				fprintf(out,"%d\t%d\t%.5lf\n",target,index[i]+1,probs[index[i]]);
			}
		}
	}
	fclose(out);

	return;
}

int main()
{
	int i,j;
	int nMaxCandidates = (int)((nMaxRegressors/2.0)*((double)(nMaxRegressors+3)))+1;
	
	
    vslNewStream(&mystream,BRNG,SEED);

	Data.NumberOfGenes = 1+NumberOfMainEffects;
	Data.SampleSize = SampleSize;   
	Data.DataFile = sDataFile;
    //read the dataset
    Data.ReadData();
    Data.Allocate(nMaxCandidates);

	//simulation parameters
	GS.tauPrior = 1;
	GS.deltaPrior = 2;
	GS.nChainIterations = nChainIterations;
	GS.nChainReplicates = nChainReplicates;

	probs = new double[Data.NumberOfGenes];
	memset(probs,0,Data.NumberOfGenes*sizeof(double));
    searchRespReg(ResponseVariable,nMaxRegressors,probs);

    //clean memory
	delete[] probs;
    Data.Cleanup();
	vslDeleteStream(&mystream);
	return(1);
}