/*
AUTHOR: ADRIAN DOBRA (ADOBRA@STAT.WASHINGTON.EDU)
*/

#include "regmodels.h"

CRegression::CRegression()
{
	Next = NULL;
	Weight = 0;
	normWeight = 0;
	nmodels = 0;
	nmaxmodels = 100000;
}

CRegression::~CRegression()
{
	return;
}

void CRegression::DeleteAll()
{
	CRegression* p = Next;
	CRegression* pnext;
	while(NULL!=p) {
		pnext = p->Next;
		p->Weight = 0;
		p->Next = NULL;
		delete p;
		p = pnext;
	}
	Next = NULL;
	return;
}

void CRegression::Delete()
{
	CRegression* p = Next;
	if(NULL==Next)
	{
		return;
	}
	double maxp = p->Weight;
	p->DeleteNotRelevant(maxp);
}

void CRegression::DeleteNotRelevant(double maxweight)
{
	CRegression* p = this;
	CRegression* pnext;
	
	while(NULL!=p->Next)
	{
		if(exp(p->Next->Weight-maxweight)<=REG_EPSILON)
		{
			pnext = p->Next;
			p->Next = pnext->Next;
			delete pnext;
		}
		else
		{
			p = p->Next;
		}
	}
	return;
}

int CRegression::AddReg(double weight,set<int> vars)
{
	CRegression* p = this;
	CRegression* pnext;
	int newModelAdded = 0;
	
	if(NULL==p->Next)
	{
		CRegression* newp = new CRegression;
		newp->Vars = vars;
		newp->Weight = weight;
		newp->Next = p->Next;
		p->Next = newp;
		nmodels++;
		newModelAdded = 1;
	}
	else
	{
		double maxweight = p->Next->Weight;
		if(weight>maxweight) //new best model is found
		{
			CRegression* newp = new CRegression;
			newp->Vars = vars;
			newp->Weight = weight;
			newp->Next = p->Next;
			p->Next = newp;
			nmodels++;
			newModelAdded = 1;
		}
		else if(exp(weight-maxweight)>REG_EPSILON)
		{
			int found = 0;
			while(NULL!=p->Next)
			{
				if(p->Next->Weight>weight)
				{
					p = p->Next;
				}
				else if((p->Next->Weight==weight)&&(p->Next->Vars==vars))
				{
					found = 1;
					break;
				}
				else
				{
					break;
				}
			}
	
			if(!found)
			{
				CRegression* newp = new CRegression;
				newp->Vars = vars;
				newp->Weight = weight;
				newp->Next = p->Next;
				p->Next = newp;
				nmodels++;
				newModelAdded = 1;
			}
		}
	}
	
    if(newModelAdded)
	{
	    //printf("nmodels = %d\n",nmodels);
		while(nmodels>nmaxmodels)
		{
			//delete the worst model (last in the list)
			p = this;
			printf("before nmodels = %d :: nmaxmodels = %d :: bestmodel = %.5lf\n",nmodels,nmaxmodels,p->Next->Weight);
			while(NULL!=p->Next->Next)
			{
				p = p->Next;
			}
			pnext = p->Next;
			p->Next = NULL;
			delete pnext;
			nmodels--;
			printf("after nmodels = %d :: nmaxmodels = %d\n",nmodels,nmaxmodels);
		}
	}
	return(newModelAdded);	
}

double CRegression::NormalizeWeights()
{
	CRegression* p = this;
	if(NULL==p->Next)
	{
		return(0);
	}
	p = p->Next;
	double maxp = p->Weight;
	p->normWeight = 1;
	double sump = 1;
	while(NULL!=p->Next)
	{
		p = p->Next;
		p->normWeight = exp(p->Weight-maxp);
		sump += p->normWeight;
	}
	p = this;
	while(NULL!=p->Next)
	{
		p = p->Next;
		p->normWeight = p->normWeight/sump;
	}
	return(sump);
}

void CRegression::MakeCovProbs(int ncov,double* probs)
{
	int i;
	double s;
	memset(probs,0,ncov*sizeof(double));
	CRegression* p = this;
	while(NULL!=p->Next)
	{
		p = p->Next;
		set<int>::iterator it;
		for(it=(p->Vars).begin();it!=(p->Vars).end();it++)
		{
			if(*it<ncov)
			{
				probs[*it] += p->normWeight;
			}
		}
	}
	return;
}

void CRegression::LoadAll(int nMaxRegressors,FILE* file)
{
	int i,j;
	double weight,normweight;
	CRegression* p = this;
	while(2==fscanf(file,"%lf %lf",&weight,&normweight))
	{
		set<int> vars;
		for(i=0;i<nMaxRegressors;i++)
		{
			if(1!=fscanf(file,"%d",&j))
			{
				printf("This file does not seem to be a correct regression file.\n");
				exit(1);
			}
			if(j>=1)
			{
				vars.insert(j-1);
			}
		}
	
		CRegression* newp = new CRegression;
		newp->Vars = vars;
		newp->Weight = weight;
		newp->normWeight = normweight;
		newp->Next = p->Next;
		p->Next = newp;
		p = newp;
	}
	return;
}

void CRegression::SaveAll(int nMaxRegressors,FILE* file)
{
	int i,j;
	CRegression* p = this;
	while(NULL!=p->Next)
	{
		p = p->Next;
		fprintf(file,"%.5lf\t%.5lf",p->Weight,p->normWeight);
		set<int>::iterator it;
		i = 0;
		for(it=(p->Vars).begin();it!=(p->Vars).end();it++)
		{
			j = *it;
			fprintf(file,"\t%d",j+1);
			i++;
		}
		for(j=i;j<nMaxRegressors;j++)
		{
			fprintf(file,"\t%d",-1);
		}
		fprintf(file,"\n");
	}
	return;
}