/*
 *  largeregcont.cpp
 *  
 *
 *  Created by Adrian Dobra on 11/22/06.
 *  Copyright 2006 __University of Washington__. All rights reserved.
 *
 */

#include "largeregcont.h"

int qsortcompare(const void * a, const void * b)
{
	int ia = *(int*)a;
	int ib = *(int*)b;
	
	if(probs[ia]>probs[ib]) return(-1);
	if(probs[ia]<probs[ib]) return(1);
	return(0);
}

void searchRespReg(int target,int maxreg)
{
	double epsilon = 0.00000000001;
	int i;
	double s;
	char buffer[1024];
	FILE* out = NULL;
	
	GS.nMaxRegressors = maxreg;
	
	sprintf(buffer,"%s.%d.%d.reg",sDataFile,target,maxreg);
	if(NULL==(out=fopen(buffer,"w")))
	{
		printf("Cannot open file [%s]\n",buffer);
		return;
	}
	GS.hybridReg(target-1,Data,probs,out);
	fclose(out);

	int index[NumberOfVariables];
	for(i=0;i<NumberOfVariables;i++)
	{
		index[i] = i;
	}
	qsort(index,NumberOfVariables,sizeof(int),qsortcompare);
	
	sprintf(buffer,"%s.%d.%d.var",sDataFile,target,maxreg);
	if(NULL==(out=fopen(buffer,"w")))
	{
		printf("Cannot open file [%s]\n",buffer);
		return;
	}
	
	s = 0;
	for(i=0;i<NumberOfVariables;i++)
	{
		if(probs[i]<epsilon)
		{
			probs[i] = 0;
		}
		s += probs[i];
	}
	
	for(i=0;i<NumberOfVariables;i++)
	{
		probs[i] /= s;
	}
	
	for(i=0;i<NumberOfVariables;i++)
	{
		if(probs[index[i]]>=epsilon)
		{
			fprintf(out,"%d\t%d\t%.5lf\n",target,index[i]+1,probs[index[i]]);
		}
	}
	fclose(out);

	return;
}

int main()
{
	int i,j;
	probs = new double[NumberOfVariables];
    /***** Initialize the RND library*****/
    vslNewStream(&mystream,BRNG,SEED);

	Data.NumberOfGenes = NumberOfVariables;
	Data.SampleSize = SampleSize;   
	Data.DataFile = sDataFile;
    //read the dataset
    Data.ReadData();
    Data.Allocate();

	//simulation parameters
	GS.tauPrior = 1;
	GS.deltaPrior = 2;
	GS.nChainIterations = nChainIterations;

	for(i=ResponseVariableMin;i<=ResponseVariableMax;i++)
	{
		for(j=nMaxRegressorsMin;j<=nMaxRegressorsMax;j++)
		{
			printf("Response [%d] maxRegressors [%d]\n",i,j);
			searchRespReg(i,j);
		}
	}

    //clean memory
    Data.Cleanup();
	vslDeleteStream(&mystream);
	delete[] probs; probs = NULL;
	return(1);
}

