/*
AUTHOR: ADRIAN DOBRA (ADOBRA@STAT.WASHINGTON.EDU)
*/
// gibbssampler.h: interface for the CGibbsSampler class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(GIBBSSAMPLER_H)
#define GIBBSSAMPLER_H

#include "mkl_vsl.h"

#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <set>
#include <vector>
using namespace std;

#if !defined(SEED)
#define SEED 7777777
#endif

#if !defined(BRNG)
#define BRNG    VSL_BRNG_MT19937
#endif

#if !defined(METHOD)
#define METHOD  0
#endif

#if !defined(DBL_MAX)
#define DBL_MAX 99999999999999999.0
#endif

#include "Data.h"
#include "equations.h"
#include "util.h"
#include "regmodels.h"

class CGibbsSampler  
{
public:
	CGibbsSampler();
	virtual ~CGibbsSampler();

	VSLStreamStatePtr stream;
	double tauPrior;
	double deltaPrior;

	//GIBBS sampling parameters
	double myPI;
	int nMaxRegressors; //this gives the maximum number of accepted regressors
	int nChainIterations;
	int nChainReplicates;
 
	vector<int> mGeneList;
	void Cleanup();

	double wishartPosterior(int npred, CData& Data);
	double ymarginalZeroPredictors(int TargetGene, CData& Data);
	double calculateLogPost(int TargetGene, set<int>& ExplanatoryGenes, CData& Data);
	int ChooseNextGene(vector<int>& PossiblePredictors);
	int ChooseNextGeneSet(set<int>& PossiblePredictors);

	double metropolisReg(int targetGene,CData& Data);
	double gibbsSamplingReg(int targetGene,CData& Data);
	double shotgunReg(int targetGene,CData& Data);
	double reducedShotgunReg(int targetGene,CData& Data);
	
	double hybridReg(int targetGene,CData& Data,double* probs,FILE* modelsfile);

	double* NormalizeWeights(double* w,int nmax);
	int WeightedSampling(int maxk,double* weights);
	int SelectEquation(int NumberOfGenes,CEquations* eq);
	int convergenceReg(int lenv,double* v1,double* v2);
};

#endif 
