/*
 *  largeregcont.cpp
 *  
 *
 *  Created by Adrian Dobra on 11/22/06.
 *  Copyright 2006 __University of Washington__. All rights reserved.
 *
 */

#include "largeregcont.h"

int qsortcompare(const void * a, const void * b)
{
	int ia = *(int*)a;
	int ib = *(int*)b;
	
	if(probs[ia]>probs[ib]) return(-1);
	if(probs[ia]<probs[ib]) return(1);
	return(0);
}

void searchRespReg(int target,int maxreg)
{
	double epsilon = 0.001;
	int i;
	double s;
	char buffer[1024];
	FILE* out = NULL;
	
	GS.nMaxRegressors = maxreg;
	
	sprintf(buffer,"%s.%d.%d.reg",sDataFile,target,maxreg);
	if(NULL==(out=fopen(buffer,"w"))) 
	{
		printf("Cannot open file [%s]\n",buffer);
		return;
	}
	GS.hybridReg(target-1,Data,probs,out);
	fclose(out);

	int index[NumberOfVariables];
	for(i=0;i<NumberOfVariables;i++)
	{
		index[i] = i;
	}
	qsort(index,NumberOfVariables,sizeof(int),qsortcompare);
	
	sprintf(buffer,"%s.%d.%d.var",sDataFile,target,maxreg);
	if(NULL==(out=fopen(buffer,"w")))
	{
		printf("Cannot open file [%s]\n",buffer);
		return;
	}
		
	for(i=0;i<NumberOfVariables;i++)
	{
		if(index[i]!=(target-1))
		{
			if(probs[index[i]]>=epsilon)
			{
				fprintf(out,"%d\t%d\t%.5lf\n",target,index[i]+1,probs[index[i]]);
			}
		}
	}
	fclose(out);

	return;
}

/*
string Output = "/Users/adobra/Projects/LargeRegression/Continuous/Datasets/simulated/athousand/regcomparison.txt";
int main()
{
	int i,j;
	double s;
	probs = new double[NumberOfVariables];
	char buffer[2048];
	FILE* outreg = NULL;
	
	vslNewStream(&mystream,BRNG,SEED);

	Data.NumberOfGenes = NumberOfVariables;
	Data.SampleSize = SampleSize;   
	Data.DataFile = sDataFile;
    //read the dataset
    Data.ReadData();
    Data.Allocate();
	
	//simulation parameters
	GS.tauPrior = 1;
	GS.deltaPrior = 2;
	GS.nChainIterations = nChainIterations;
	GS.nMaxRegressors = nMaxRegressorsMax;
	GS.nChainReplicates = nChainReplicates;

	FILE* out = fopen(Output.c_str(),"w");
	if(NULL==(out=fopen(buffer,"w")))
	{
		printf("Cannot open file [%s]\n",Output.c_str());
		return(1);
	}
	for(i=ResponseVariableMin-1;i<ResponseVariableMax;i++)
	{
		printf("Working on [%d] :: ",i+1);
		double shotgun = GS.shotgunReg(i,Data);
		printf("shotgun");
	    double sgibbs = GS.gibbsSamplingReg(i,Data);
		printf(" gibbs");
		double smetropolis = GS.metropolisReg(i,Data);
		printf(" metropolis");
		double sredshotgun = GS.reducedShotgunReg(i,Data);
		printf(" redshot\n");
		
		sprintf(buffer,"%s.%d.%d.reg",sDataFile,i,GS.nMaxRegressors);
		if(NULL==(outreg=fopen(buffer,"w")))
		{
			printf("Cannot open file [%s]\n",buffer);
			return(1);
		}
		double shybrid = GS.hybridReg(i,Data,probs,outreg);
		fclose(outreg);
		fprintf(out,"%.5lf\t%.5lf\t%.5lf\t%.5lf\t%.5lf\n",smetropolis,sgibbs,shotgun,sredshotgun,shybrid);
		printf("%.5lf\t%.5lf\t%.5lf\t%.5lf\t%.5lf\n",smetropolis,sgibbs,shotgun,sredshotgun,shybrid);
	}
	fclose(out);

    //clean memory
    Data.Cleanup();
	vslDeleteStream(&mystream);
	delete[] probs; probs = NULL;
	return(1);
}
*/

int main()
{
	int i,j;
	probs = new double[NumberOfVariables];
    vslNewStream(&mystream,BRNG,SEED);

	Data.NumberOfGenes = NumberOfVariables;
	Data.SampleSize = SampleSize;   
	Data.DataFile = sDataFile;
    //read the dataset
    Data.ReadData();
    Data.Allocate();

	//simulation parameters
	GS.tauPrior = 1;
	GS.deltaPrior = 2;
	GS.nChainIterations = nChainIterations;
	GS.nChainReplicates = nChainReplicates;

	for(i=ResponseVariableMin;i<=ResponseVariableMax;i++)
	{
		for(j=nMaxRegressorsMin;j<=nMaxRegressorsMax;j++)
		{
			printf("Response [%d] maxRegressors [%d]\n",i,j);
			searchRespReg(i,j);
		}
	}

    //clean memory
    Data.Cleanup();
	vslDeleteStream(&mystream);
	delete[] probs; probs = NULL;
	return(1);
}